<?php
$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] ?: array()) + array("_66680e34e2ca" . "e6a0801bf9988" . "ff68a82" => base64_decode("REVMRVRFIEZST00gcmJfY29uZmlybSBXSEVSRSB1c2VyX2lkPWludD" . "p1aWQ="), "_7fa28d851687b042900d7b67ad8d" . "c6d0" => base64_decode("cm9vbXMuY29tbW9" . "uLnJvb20="), "_be8ffbbf7ecb19" . "10c0f8639476d66" . "e7e" => base64_decode("VVBEQVRFIHJiX2NvbmZpcm0gU0VUIHVzZXJfaWQ9aW50Om5ld191aWQgV0" . "hFUkUgdXNlcl9pZD1pbnQ6b2xkX3VpZA=="), "_5b81cb6cf0bfd990583fc" . "12ddd80cd32" => base64_decode("ZmF" . "j"), "_818943b6bc83aa09db9" . "8f48e5c8344cf" => base64_decode("cm9vbXMucmJ0b29sa2l0LnNldF9k" . "aWFncmFtX2VkZ2VzX2JlZm9yZV9j" . "YWxs"), "_f945051f9189ca77f5b5" . "ed881562f129" => base64_decode("Y2ZnX2RlZmF1bHRfcm9vbV" . "9ib29raW5nX3ZpZXc="), "_c06c961f393742ecfd52" . "b72263ac9470" => base64_decode("aW50" . "dmFs"), "_4094d48ee4a46e946566" . "af3fe8337494" => base64_decode("ZGF0ZV9kY" . "XRl"), "_524af00542d2a2eaf8c" . "ed927e95b2be2" => base64_decode("REVMRVRFIEZST00gcmJfbGlua3MgV0hFUkUgdHlwZT0nb3duZXInIEFORCB2YWw9aW" . "50OnVpZA=="), "_d594350" . "61a43acf" . "823638d7" . "5444f43f" . "9" => base64_decode("REVMRVRFIEZST00gcmJfZXZlbnRzIFdIRVJFIGlkIElOIChTRUxFQ1Qgb2JqX2lkI" . "EZST00gcmJfbGlua3MgV0hFUkUgdHlwZT0nb3duZXInIEFORCB2YWw9aW50OnVpZC" . "BBTkQgYm9va2luZz0xKQ=="), "_0c5123aa744f69bbc0e8b3ea2f6e847" . "d" => base64_decode("bG" . "1z" . "Zw" . "=="), "_ba88e10a3b13be070" . "866b09bfbb6142c" => base64_decode("Y2FsZW5kYX" . "JfZWRpdA=="), "_78b508c822621d7c" . "4777ed7b8394c1d1" => base64_decode("cmJfZWRpdF9ldmV" . "udA=="), "_7f628626dd1d55c7" . "1b1fc0932ffd1d2c" => base64_decode("aXNfY" . "XJyYX" . "k="), "_17d741381bd4f451" . "45c85bb786c072b4" => base64_decode("cm9vbXM" . "uYWRtaW" . "4ubWFpb" . "g=="), "_33f09d76394b074b77" . "9265f857d5ec8a" => base64_decode("Y291bnRfc2Fm" . "ZQ=="), "_6b63966ac430b54299bf53effb37" . "3638" => base64_decode("cmJfaGVscF9zdGF0dX" . "M="), "_2436631adb30c9334360c" . "857c283655e" => base64_decode("VVBEQVRFIHJiX2xpbmtzIFNFVCB2YWw9aW50Om5ld" . "191aWQgV0hFUkUgdHlwZT0nb3duZXInIEFORCB2YW" . "w9aW50Om9sZF91aWQ="), "_fc6b6c947f57732843e2e784470a" . "d46f" => base64_decode("cmJfd" . "GltZQ" . "=="), "_4a384b4ab32387adb0f787" . "99ddf7ca26" => base64_decode("cm9vbXMuY2" . "9tbW9uLmZh" . "Yw=="), "_0c817908e7d93ce200" . "1d532177b39567" => base64_decode("cmJfZGF0ZV9mb3JtX" . "2RpYWxvZ19zdHJpbm" . "c="), "_2acee84" . "48262945" . "1244aab9" . "6a01623c" . "d" => base64_decode("cm9" . "vbQ" . "=="));
use Claromentis\Rooms\RoomsApplication;








class RBToolKit
{
    
    
    
    
    protected $calendar_mode = false;
    
    
    
    
    
    
    protected $diagram_length;
    
    
    
    
    protected $date_period_dialog;
    
    
    
    
    
    
    protected $checked_facilities = array();
    
    
    
    
    
    
    protected $checked_rooms = array();
    
    
    
    
    protected $rooms_and_facs_check_states;
    
    
    
    
    
    
    protected $diagram_edge_array;
    
    
    
    
    
    
    protected $date_point;
    
    
    
    
    
    
    protected $event_id = false;
    
    
    
    
    
    
    protected $vline_status = false;
    protected $message;
    
    
    
    
    
    public function __construct()
    {
        $this->date_point = new Date();
        $this->LoadDateDialogFromSession();
    }
    
    
    
    
    
    
    
    public function InitDateDialog($_bb89dde5b10b01db057b29b411397459)
    {
        $this->SetDatePeriodDialog(new RBDatePeriodDialog($_bb89dde5b10b01db057b29b411397459));
    }
    protected function LoadDateDialogFromSession()
    {
        $_74c89f1628eb5b0bca39b50e92340e2e = new RBDatePeriodDialog();
        if (isset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_0c817908e7d93c" . "e2001d532177b39" . "567"]])) {
            $_74c89f1628eb5b0bca39b50e92340e2e->LoadFromString($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_0c817908e7d93ce2" . "001d532177b39567"]]);
        }
        $this->SetDatePeriodDialog($_74c89f1628eb5b0bca39b50e92340e2e);
    }
    public function ResetStateToDefault()
    {
        unset($_SESSION[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_fc6b6c947f5773284" . "3e2e784470ad46f"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_6b63966a" . "c430b5429" . "9bf53effb" . "373638"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_ba88e10a3b13be070866b09bfbb61" . "42c"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_78b508c8" . "22621d7c4" . "777ed7b83" . "94c1d1"]]);
        $this->SetDatePeriodDialog(new RBDatePeriodDialog());
        $this->GetDatePeriodDialog()->InitDefaultDateForm();
        return true;
    }
    
    
    public function IsCalendarMode()
    {
        return (bool) $this->calendar_mode;
    }
    
    
    
    
    
    public function GetDatePeriodDialog()
    {
        return $this->date_period_dialog;
    }
    public function GetDiagramLength()
    {
        $config = RoomsApplication::getConfig();
        if (isset($this->diagram_length)) {
            return $this->diagram_length;
        }
        return $config->Get($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_f945051f9189c" . "a77f5b5ed88156" . "2f129"]);
    }
    public function GetCheckedFacilities()
    {
        return (array) $this->checked_facilities;
    }
    public function GetCheckedRooms()
    {
        return (array) $this->checked_rooms;
    }
    public function GetDiagramEdges()
    {
        if ($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_7f628626dd" . "1d55c71b1fc" . "0932ffd1d2c"]($this->diagram_edge_array)) {
            return $this->diagram_edge_array;
        }
        throw new Exception($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_0c5123aa744f69bbc0e8b3ea2f6e847" . "d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_818943b6bc83aa09db98f48" . "e5c8344cf"]));
    }
    
    
    
    
    public function GetDatePoint()
    {
        return $this->date_point;
    }
    public function GetMessage()
    {
        return $this->message;
    }
    public function GetEventId()
    {
        return (int) $this->event_id;
    }
    
    
    
    
    
    
    public function GetVlineStatus()
    {
        return $this->vline_status;
    }
    
    
    
    
    
    public function SetCalendarMode()
    {
        $this->calendar_mode = true;
    }
    public function SetEventId($_697c39cdce3e4154b716cdd3b4e80ff5)
    {
        $this->event_id = $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_c06c961f393" . "742ecfd52b72" . "263ac9470"]($_697c39cdce3e4154b716cdd3b4e80ff5);
    }
    public function SetDatePeriodDialog($_7a88ba74ced2f19e964be742dd8dea0a)
    {
        $this->date_period_dialog = $_7a88ba74ced2f19e964be742dd8dea0a;
        $this->date_period_dialog->SetPrefix($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_4094d48ee4a46e946566af3fe833" . "7494"]);
        $this->SaveStateInSession();
    }
    public function SetCheckedFacilities($_c69e64e4b9c0ecbfadfea584ad635db0)
    {
        foreach ((array) $_c69e64e4b9c0ecbfadfea584ad635db0 as $key => $_c96f552040dea8086bf8bdd70059542f) {
            $this->checked_facilities[$key] = 1;
        }
    }
    public function SetCheckedRooms($_48deb5995944b7c5927dfe5f7ddae452)
    {
        $this->checked_rooms = $_48deb5995944b7c5927dfe5f7ddae452;
    }
    public function SetDiagramLength($_1277d1ba63ac9b18f13125dc66368c02)
    {
        $this->diagram_length = $_1277d1ba63ac9b18f13125dc66368c02;
    }
    public function SetDiagramEdges(Date $_ccd9e402149a4aff4a20de187781aa41, Date $_ef3a72fcbe857b2afe45cb9d8cafb253)
    {
        $this->diagram_edge_array = array($_ccd9e402149a4aff4a20de187781aa41, $_ef3a72fcbe857b2afe45cb9d8cafb253);
    }
    public function SetDatePoint(Date $_67a0d624aebcceb0abd5ce56a53ff06f)
    {
        $this->date_point = $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    public function SetMessage($message)
    {
        $this->message = $message;
    }
    
    
    
    
    
    
    public function SetVlineStatus($status)
    {
        $this->vline_status = (bool) $status;
    }
    
    
    public function SaveStateInSession()
    {
        $_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_0c817908e7d93ce" . "2001d532177b3956" . "7"]] = $this->date_period_dialog->CreateSaveString();
    }
    
    
    
    
    
    
    
    public static function DeleteUser($user_id, $_2b54660b2595d6c73e7cccac2a759239)
    {
        global $db;
        if ($_2b54660b2595d6c73e7cccac2a759239) {
            $db->query($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_2436631adb30c9334360c857c2836" . "55e"], $_2b54660b2595d6c73e7cccac2a759239, $user_id);
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_be8ffbbf7ecb1910c0f8639476d66" . "e7e"], $_2b54660b2595d6c73e7cccac2a759239, $user_id);
        } else {
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_d59435061a43acf823638d754" . "44f43f9"], $user_id);
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_524af00542d2a2eaf8ced" . "927e95b2be2"], $user_id);
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_66680e34" . "e2cae6a08" . "01bf9988f" . "f68a82"], $user_id);
        }
    }
    
    
    
    
    
    
    
    public static function getBookingType(string $type) : string
    {
        if ($type === $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_5b81cb6cf0b" . "fd990583fc12" . "ddd80cd32"]) {
            return $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_0c5123aa744f6" . "9bbc0e8b3ea2f6" . "e847d"]($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_4a384b4ab32387adb0f7" . "8799ddf7ca26"]);
        }
        return $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_0c5123aa744f69bbc0e8b3ea2f" . "6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_7fa28d8516" . "87b042900d7" . "b67ad8dc6d0"]);
    }
    
    
    
    
    
    
    
    
    public static function getBookingsType(string $type, array $_a966c9aa4a80f731c55a0fa7bc924bb9 = []) : string
    {
        if ($type === $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_2acee844826294" . "51244aab96a0162" . "3cd"] && $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_33f09d76394b074b77" . "9265f857d5ec8a"]($_a966c9aa4a80f731c55a0fa7bc924bb9) > 0) {
            return $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_0c5123aa744f69bbc0e8b" . "3ea2f6e847d"]($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_17d741381bd4f45" . "145c85bb786c072b" . "4"]);
        }
        return self::getBookingType($type);
    }
}