<?php
$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] ?: array()) + array("_511be8cd8d8bae4efce6b6d" . "d4ff70530" => base64_decode("ZWRpdF9ldmVu" . "dA=="), "_9ec0673d" . "3f363160c" . "ec842dd84" . "da335d" => base64_decode("ZGVsZX" . "RlX2V2" . "ZW50"), "_66aaa4202afc087ccc629429b" . "94f26cf" => base64_decode("bmV" . "4dA" . "=="), "_e21aea73c33e96ef626d3b3bf962359" . "3" => base64_decode("YXJyYXlfcHVzaA" . "=="), "_62c6c04046599d440b89fcd" . "177155a32" => base64_decode("cm9vbXMucmJhY3Rpb24uZXZlbnRfbm90X2Z" . "vdW5k"), "_5b81cb6cf0bfd990583fc12ddd80cd" . "32" => base64_decode("Zm" . "Fj"), "_4dbcdc0af6ad69a200eb60c81e263" . "05c" => base64_decode("M" . "D" . "A" . "="), "_bf597f0023796d52ab864e" . "5096729090" => base64_decode("cHJl" . "dg=="), "_78b508c822621d7c4777e" . "d7b8394c1d1" => base64_decode("cmJfZWRpdF9ldmV" . "udA=="), "_59be04fc0edf7507f42c6c8" . "0666dc1e3" => base64_decode("UEhQX" . "1NFTE" . "Y="), "_2acee84482629451244aab96a01" . "623cd" => base64_decode("cm" . "9v" . "bQ" . "=="), "_0c5123aa744f69bbc0e8b3ea2f6e" . "847d" => base64_decode("bG1zZw=" . "="), "_d706c160e45bf74" . "34fff82a5976f0e1" . "9" => base64_decode("YXJyYXlfa2V" . "5cw=="), "_7277920cd79b72818ba49" . "8a7b06d9f73" => base64_decode("cm9vbXMucmJ" . "hY3Rpb24uYm" . "9va2luZ193Y" . "XNfZGVs"), "i" . "d" => base64_decode("a" . "W" . "Q" . "="), "edit" . "_id" => base64_decode("ZWRpd" . "F9pZA" . "=="), "n" . "a" . "m" . "e" => base64_decode("bm" . "Ft" . "ZQ" . "=="), "_25867e3e3db28969253f3a" . "370c3166ba" => base64_decode("ZGVzY" . "w=="), "_04014b4c4cd7f8beafc06c912139b97" . "9" => base64_decode("aHR0" . "cFJl" . "ZGly" . "ZWN0"), "_be2f530b7f79423" . "353d454b8acd8ecb" . "4" => base64_decode("bG" . "9u" . "Zw" . "=="), "_2ec9a485dd285c28c8e85f01a894" . "5982" => base64_decode("cm9vbXMu" . "dG9vbGtp" . "dA=="));
use Claromentis\Rooms\Exception\EventNotFoundException;






class RBActionsProcessor extends ErrorHandler
{
    const DIAGRAM_PERIOD_WEEK = 0;
    const DIAGRAM_PERIOD_BIWEEK = 1;
    const DIAGRAM_PERIOD_DAY = 2;
    protected $redir = false;
    protected $message;
    protected $is_error = false;
    protected $allow_redirect = true;
    
    
    
    
    protected $toolkit;
    public function __construct($_8360eb382bc61a4bb036cc1aa0860698 = true)
    {
        global $g_application;
        $this->allow_redirect = $_8360eb382bc61a4bb036cc1aa0860698;
        $this->toolkit = $g_application[$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_2ec9a485dd285c28c8e85f01a8" . "945982"]];
        
        
    }
    
    
    
    
    
    
    public function ProcessAction($action)
    {
        switch ($action) {
            case $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9ec0673d3f363" . "160cec842dd84d" . "a335d"]:
                gpc::CheckToken();
                $this->_delEvent();
                break;
            case $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_511be8cd8d8bae4efce6b6dd4ff70" . "530"]:
                $this->_editEvent();
                break;
            case $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_66aaa4202afc087ccc629429b94f26" . "cf"]:
                $this->_processNextScreen();
                break;
            case $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_bf597f0023796d52ab864e5096" . "729090"]:
                $this->_processPrevScreen();
                break;
        }
        $this->_setGraphInterval();
        $this->toolkit->SaveStateInSession();
        if ($this->redir) {
            $this->_redirPage();
        }
    }
    
    
    
    
    protected function _editEvent()
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new RBBooking(new RBFacade());
        $_68ffaaa31e3ba49ed9d6159fbee9f043->Load($this->toolkit->GetEventId());
        $_343a395319323dd7609bcbc465b4d034 = $_68ffaaa31e3ba49ed9d6159fbee9f043->_getChildList();
        $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_e21aea73c33e96ef626d" . "3b3bf9623593"]($_343a395319323dd7609bcbc465b4d034, $_68ffaaa31e3ba49ed9d6159fbee9f043->id);
        $_SESSION[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_78b508c8226" . "21d7c4777ed7" . "b8394c1d1"]] = array($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["i" . "d"] => $_343a395319323dd7609bcbc465b4d034, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["ed" . "it" . "_i" . "d"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->id, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["nam" . "e"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->name, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_25867e3e3db2896" . "9253f3a370c3166b" . "a"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->desc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_2acee84482629451244aab96a016" . "23cd"] => $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_d706c160e45bf7434fff82a" . "5976f0e19"]($_68ffaaa31e3ba49ed9d6159fbee9f043->GetObjList($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_2acee844826294" . "51244aab96a0162" . "3cd"])));
        $_343a395319323dd7609bcbc465b4d034 = $this->_createFacArray($_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->_initFormFromEditingEvent($_68ffaaa31e3ba49ed9d6159fbee9f043);
    }
    
    
    
    
    
    
    
    public function UpdateEvent($_697c39cdce3e4154b716cdd3b4e80ff5, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75)
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new RBBooking(new RBFacade());
        $_68ffaaa31e3ba49ed9d6159fbee9f043->Load($_697c39cdce3e4154b716cdd3b4e80ff5);
        $this->_changeEvent($_68ffaaa31e3ba49ed9d6159fbee9f043, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75);
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_c8b38c7133c2e8460c1cca42230ac6c2 = $_dcd18f1ae5fbc1bd429492db158908aa->DeleteEvent($_68ffaaa31e3ba49ed9d6159fbee9f043->id);
    }
    
    
    
    
    
    
    
    
    
    protected function _changeEvent($_68ffaaa31e3ba49ed9d6159fbee9f043, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75)
    {
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_dcd18f1ae5fbc1bd429492db158908aa->ChangeEvent($this->toolkit->GetDatePeriodDialog(), $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75, $this->toolkit->GetCheckedFacilities(), AuthUser::I()->GetId(), $_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->_initDateForm(new Date($this->toolkit->GetDatePeriodDialog()->GetHeadDatePeriod()->start[$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_be2f530b7f79423353d454b8acd8" . "ecb4"]] . $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_4dbcdc0af" . "6ad69a200e" . "b60c81e263" . "05c"]));
        
        
    }
    
    
    
    
    
    protected function _createFacArray($_68ffaaa31e3ba49ed9d6159fbee9f043)
    {
        $_343a395319323dd7609bcbc465b4d034 = $_68ffaaa31e3ba49ed9d6159fbee9f043->GetObjList($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_5b81cb6cf0bfd9" . "90583fc12ddd80c" . "d32"]);
        $_094e18a2dde09a1246a956dacefdbc9c = array();
        foreach ((array) $_343a395319323dd7609bcbc465b4d034 as $key => $_c96f552040dea8086bf8bdd70059542f) {
            $_5b81cb6cf0bfd990583fc12ddd80cd32 = new RBFac(new RBFacade());
            $_5b81cb6cf0bfd990583fc12ddd80cd32->Load($key);
            $_094e18a2dde09a1246a956dacefdbc9c[$_5b81cb6cf0bfd990583fc12ddd80cd32->pid][$key] = 1;
        }
        return $_094e18a2dde09a1246a956dacefdbc9c;
    }
    
    
    
    
    protected function _initFormFromEditingEvent($_68ffaaa31e3ba49ed9d6159fbee9f043)
    {
        $_a335e14ddefbedf8ca192d19ab93691e = new RBDatePeriodDialog();
        $_a335e14ddefbedf8ca192d19ab93691e->CreateFromEvent($_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->toolkit->SetDatePeriodDialog($_a335e14ddefbedf8ca192d19ab93691e);
    }
    
    
    
    
    
    
    
    
    
    public function AddEvent($_68850b1507f146443ff5d1f5a5460e75, $_5693d84b45564f912e36404cbe8957e8, $_df4ae3ddb85ca6bd03e27e1d86fa3c41)
    {
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_18cb991d3787967aac03336ac7811b3d = $_dcd18f1ae5fbc1bd429492db158908aa->CreateEvent($this->toolkit->GetDatePeriodDialog(), $_5693d84b45564f912e36404cbe8957e8, $_df4ae3ddb85ca6bd03e27e1d86fa3c41, $_68850b1507f146443ff5d1f5a5460e75, $this->toolkit->GetCheckedFacilities(), AuthUser::I()->GetId());
        $this->_initDateForm(new Date($this->toolkit->GetDatePeriodDialog()->GetHeadDatePeriod()->start[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_be2f530b7f79423" . "353d454b8acd8ecb" . "4"]] . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_4dbcdc0af6ad69a200eb60c8" . "1e26305c"]));
        return $_18cb991d3787967aac03336ac7811b3d;
    }
    
    
    
    
    protected function _initDateForm($_91d10773c15d92f509551b22650c8a4e)
    {
        $this->toolkit->SetDatePoint($_91d10773c15d92f509551b22650c8a4e);
        $this->toolkit->GetDatePeriodDialog()->InitDefaultDateForm($_91d10773c15d92f509551b22650c8a4e);
    }
    
    
    
    
    protected function _delEvent($_81c1fba056fca0b94d585482be6fe046 = false)
    {
        if (!$_81c1fba056fca0b94d585482be6fe046) {
            $_81c1fba056fca0b94d585482be6fe046 = $this->toolkit->GetEventId();
        }
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        try {
            $_c8b38c7133c2e8460c1cca42230ac6c2 = $_dcd18f1ae5fbc1bd429492db158908aa->DeleteEvent($_81c1fba056fca0b94d585482be6fe046);
            $this->_initDateForm(new Date($_c8b38c7133c2e8460c1cca42230ac6c2 . $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_4dbcdc0af6ad69a200eb6" . "0c81e26305c"]));
            $this->message = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_0c5123aa744f69bbc0e8b3ea2f6e847" . "d"]($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_7277920cd" . "79b72818ba" . "498a7b06d9" . "f73"]);
        } catch (EventNotFoundException $e) {
            $this->is_error = true;
            $this->message = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_0c5123aa744f69bbc0e8b3ea2f6e84" . "7d"]($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_62c6c04" . "046599d4" . "40b89fcd" . "177155a3" . "2"]);
        }
        $this->redir = true;
    }
    
    
    
    
    protected function _redirPage()
    {
        if ($this->allow_redirect) {
            $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_04014b4c4cd7f8beafc06c912139" . "b979"]($_SERVER[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_59be04fc0edf7507f42c6c8" . "0666dc1e3"]], $this->message, $this->is_error);
            exit;
        }
    }
    
    
    
    
    protected function _processNextScreen()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_WEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek());
                break;
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek()->getBeginOfNextWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getNextDay());
                break;
        }
    }
    
    
    
    
    protected function _processPrevScreen()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_WEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfPrevWeek());
                break;
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfPrevWeek()->getBeginOfPrevWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getPrevDay());
                break;
        }
    }
    
    
    
    
    protected function _setGraphInterval()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfWeek(), $_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek()->getEndOfWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f, $_67a0d624aebcceb0abd5ce56a53ff06f);
                break;
            default:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfWeek(), $_67a0d624aebcceb0abd5ce56a53ff06f->getEndOfWeek());
                break;
        }
    }
}